# coding: utf-8
from rest_framework import viewsets
from rest_framework.decorators import action
from rest_framework.request import Request

from before_request import before_request
from inspect_report.dbhelper import db_static_score, db_seat_rule, db_seat_check, db_seat_area, db_static_rule, \
    set_city_country_by_team_name
from datetime import datetime
from django.http import HttpResponse
import logging
import csv
import codecs
from django.utils.http import urlquote

from inspect_report.pagehelper import set_object_seat_name

logger = logging.getLogger(__name__)


class DataApi(viewsets.ViewSet):
    authentication_classes = ()
    permission_classes = ()

    @action(['get'], detail=False)
    @before_request
    def static_score_export(self, req: Request):
        """
        概览-得分统计-导出
        :param req:
        :return:
        """

        scores = db_static_score(req)

        scores = set_city_country_by_team_name(scores, 'area')

        response = HttpResponse(content_type='text/csv')
        file_name = '组长概览_' + datetime.now().strftime('%Y%m%d%H%M%S') + '.csv'
        response['Content-Type'] = 'application/octet-stream'
        response['Content-Disposition'] = 'attachment;filename="{0}"'.format(urlquote(file_name))
        # 设置编码,放置中文乱码
        response.write(codecs.BOM_UTF8)
        writer = csv.writer(response)
        # 设置表头
        header = ['地市', '县', '团队', '全部会话数', '触发违规项次数', '服务类平均分', '业务类平均分', '总平均分（包含0分项）', '触发0分项次数']
        writer.writerow(header)
        # 设置表数据
        for r in scores:
            row = [r['city'], r['country'], r['area'], r['total_session'], r['validate_num'], r['avg_score_svc'], r['avg_score_bus'],
                   r['avg_score'], r['validate_zero']]
            writer.writerow(row)
        return response

    @action(['get'], detail=False)
    @before_request
    def static_rule_export(self, req: Request):
        """
        违规项统计-导出
        :param req:
        :return:
        """

        data_sort = db_static_rule(req)

        response = HttpResponse(content_type='text/csv')
        file_name = '违规项分析_' + datetime.now().strftime('%Y%m%d%H%M%S') + '.csv'
        response['Content-Type'] = 'application/octet-stream'
        response['Content-Disposition'] = 'attachment;filename="{0}"'.format(urlquote(file_name))
        # 设置编码,放置中文乱码
        response.write(codecs.BOM_UTF8)
        writer = csv.writer(response)
        # 设置表头
        header = ['违规项', '违规次数', '通话次数', '违规占比']
        writer.writerow(header)
        # 设置表数据
        for r in data_sort:
            row = [r['rule'], r['count'], r['call_count'], r['ratio']]
            writer.writerow(row)
        return response

    @action(['get'], detail=False)
    @before_request
    def seat_rule_export(self, req: Request):
        """
        坐席违规分析-按照得分-导出
        :param req:
        :return:
        """

        total_count, data_sort = db_seat_rule(req)

        response = HttpResponse(content_type='text/csv')
        file_name = '坐席违规_' + datetime.now().strftime('%Y%m%d%H%M%S') + '.csv'
        response['Content-Type'] = 'application/octet-stream'
        response['Content-Disposition'] = 'attachment;filename="{0}"'.format(urlquote(file_name))
        # 设置编码,放置中文乱码
        response.write(codecs.BOM_UTF8)
        writer = csv.writer(response)
        # 设置表头
        header = ['坐席id', '坐席姓名', '全部会话数', '违规会话数', '违规占比']
        writer.writerow(header)
        # 设置表数据
        for r in data_sort:
            row = [r['agentName'], r['seatName'], r['validate_session'], r['total_session'], r['ratio']]
            writer.writerow(row)
        return response

    @action(['get'], detail=False)
    @before_request
    def seat_area_export(self, req: Request):
        """
        地市坐席成绩分析-导出
        :param req:
        :return:
        """
        scores = db_seat_area(req)
        scores = set_object_seat_name(scores)
        response = HttpResponse(content_type='text/csv')
        file_name = '坐席成绩_' + datetime.now().strftime('%Y%m%d%H%M%S') + '.csv'
        response['Content-Type'] = 'application/octet-stream'
        response['Content-Disposition'] = 'attachment;filename="{0}"'.format(urlquote(file_name))
        # 设置编码,放置中文乱码
        response.write(codecs.BOM_UTF8)
        writer = csv.writer(response)
        # 设置表头
        header = ['团队', '坐席工号', '坐席名称', '全部会话数', '触发违规项次数', '服务类平均分', '业务类平均分', '平均分', '触发0分项次数']
        writer.writerow(header)
        # 设置表数据
        for r in scores:
            row = [r['area'], r['agentName'], r['seatName'], r['total_session'], r['validate_num'], r['avg_score_svc'],
                   r['avg_score_bus'], r['avg_score'], r['validate_zero']]
            writer.writerow(row)
        return response

    @action(['get'], detail=False)
    def seat_check_export(self, req: Request):
        """
        坐席绩效考核汇总-导出
        :param req:
        :return:
        """
        total_count, return_data = db_seat_check(req)

        response = HttpResponse(content_type='text/csv')
        file_name = '质检绩效考核_' + datetime.now().strftime('%Y%m%d%H%M%S') + '.csv'
        response['Content-Type'] = 'application/octet-stream'
        response['Content-Disposition'] = 'attachment;filename="{0}"'.format(urlquote(file_name))
        # 设置编码,放置中文乱码
        response.write(codecs.BOM_UTF8)
        writer = csv.writer(response)
        # 设置表头
        header = ['时间', '地市', '坐席工号', '文件名', '通话时长(s)', '服务用语(15%)', '开场白(5%)', '结束语(3%)', '服务态度(5%)',
                  '语速识别(5%)', '静音识别(5%)', '异议处理(10%)', '业务促成(10%)', '预约及流转(10%)', '服务介绍(10%)',
                  '未提供报价(2%)', '成功件信息核实(20%)', '违规则0分(100%)', '敏感词(100%)', '得分']

        writer.writerow(header)
        # 设置表数据
        for r in return_data:
            row = [r['createdAt'], r['area'], r['agentName'], r['filename'], r['remainTime'], r['fwyy'], r['kcb'],
                   r['jsy'],
                   r['fwtd'], r['yssb'], r['jysb'], r['yycl'], r['ywcc'], r['yyjlz'], r['fwjs'], r['wtgbj'],
                   r['cgjxxhs'], r['wgzlf'], r['mgc'], r['total_score']]
            writer.writerow(row)
        return response
